// Create context menu item when extension is installed
chrome.runtime.onInstalled.addListener(() => {
  chrome.contextMenus.create({
    id: "search-perplexity",
    title: "Search on Perplexity",
    contexts: ["selection"]
  });
});

// Handle context menu item click
chrome.contextMenus.onClicked.addListener((info, tab) => {
  if (info.menuItemId === "search-perplexity") {
    // Validate text selection
    if (!info.selectionText || info.selectionText.trim() === "") {
      chrome.notifications.create({
        type: "basic",
        iconUrl: "icons/icon128.png",
        title: "Error",
        message: "Please highlight text to search."
      });
      return;
    }

    try {
      // Encode the selected text and create Perplexity search URL
      const query = encodeURIComponent(info.selectionText);
      const url = `https://www.perplexity.ai/search?q=${query}`;
      
      // Open new tab with search results
      chrome.tabs.create({ url }, (tab) => {
        console.log(`Tab created with URL: ${url}`);
      });
    } catch (error) {
      console.error('Error processing search:', error);
      chrome.notifications.create({
        type: "basic",
        iconUrl: "icons/icon128.png",
        title: "Error",
        message: "Failed to process search. Please try again."
      });
    }
  }
}); 